=======
Credits
=======

..
        TODO: This should probably reference the Credits section of README.rst

This code originated from a post_ by Adam Urbanczyk to the CadQuery_ forum_.

Development Lead
----------------

* Wink Saville <wink@saville.com>

Contributors
------------

None yet. Why not be the first?

.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
.. _post: https://groups.google.com/g/cadquery/c/5kVRpECcxAU/m/7no7_ja6AAAJ
.. _CadQuery: https://github.com/cadquery/cadquery
.. _forum: https://groups.google.com/g/cadquery
